<?php
namespace PME\Controllers\Cardapio;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager\Doctrine\NameProvider;
use Zeedhi\Framework\DataSource\FilterCriteria;

class AnaliseNutricional extends \PME\Services\TeknisaCrud {
	protected $connection;
	protected $environment;
	protected $utilities;

  public function __construct($crudService, $parameterBag, $connection, $environment, $utilities) {
		parent::__construct($crudService, $parameterBag);
		$this->connection = $connection;
		$this->environment = $environment;
		$this->utilities = $utilities;
	}
	
	public function procedureNutrCard(DTO\Request\Row $request, DTO\Response $response) {
		$row = $request->getRow();
		$cdfilial = empty($row['aggregated']) ? $row['cdfilcentpme'] : $row['aggregated'];
		$nrSeqNutr = $this->utilities->callProcedureNutrCard($row['cdfilcentpme'], $cdfilial, $row['service']['CDSERVFILI'], 'T', 'S', $row['initialDate'], $row['finalDate'], $row['typeMenu']['CDTIPOCARD']);
		$response->addDataSet(new DataSet('nrseqnutr', [$nrSeqNutr]));
	}

	public function deleteNutrTrab(DTO\Request\Row $request, DTO\Response $response) {
		$row = $request->getRow();
		$query = "DELETE FROM NUTRTRAB WHERE NRSEQUNUTR =: NRSEQUNUTR";
		$params = array(
			"NRSEQUNUTR" => $row[0]
		);
		$stmt = $this->connection->prepare($query)->execute($params);
		$response->addDataSet(new DataSet('response', ['true']));
	}

	public function calculateInfoNutr(DTO\Request\Row $request, DTO\Response $response) {
		$row = $request->getRow();
		$query = "SELECT NT.CDNUTRCALC, NU.NMNUTRIENTE, NU.SGUNIDADE, SUM(NT.QTNUTRCALC) AS QTNUTRIENTE
							FROM NUTRTRAB  NT, NUTRIENTE NU
							WHERE (NT.NRSEQUNUTR   = :P_NRSEQUNUTR) AND(NT.CDFILINUTR   = :P_CDFILINUTR) AND (NT.CDSERVNUTR   = :P_CDSERVNUTR) AND
								(NT.DTREFENUTR   = :P_DTREFENUTR) AND (NT.CDDIETNUTR   = :P_CDDIETNUTR) AND (NT.CDNUTRCALC IN (:CDCARBOHIDRA, :CDPROTEINA, :CDALCOOL, :CDLIPIDIOS)) AND
								(NU.CDNUTRIENTE  = NT.CDNUTRCALC) AND (NRSEQUNUTR IS NOT NULL) AND ( (:P_CDPRATNUTR = 'T') OR (INSTR(:P_CDPRATNUTR, NT.CDPRATNUTR) <> 0))                                
							GROUP BY NT.CDNUTRCALC, NU.NMNUTRIENTE, NU.SGUNIDADE
							ORDER BY  NT.CDNUTRCALC";
		$params = array(
			"P_NRSEQUNUTR" => $row['NRSEQUNUTR'],
			"P_CDFILINUTR" => $row['CDFILINUTR'],
			"P_CDSERVNUTR" => $row['CDSERVNUTR'],
			"P_DTREFENUTR" => $row['DTREFENUTR'],
			"P_CDDIETNUTR" => $row['CDDIETNUTR'],
			"P_CDPRATNUTR" => $row['CDPRATO'],
			"CDCARBOHIDRA" => $row['CDCARBOHIDRA'],
			"CDPROTEINA" => $row['CDPROTEINA'],
			"CDALCOOL" => $row['CDALCOOL'],
			"CDLIPIDIOS" => $row['CDLIPIDIOS']
		);
		$stmt = $this->connection->prepare($query);
		$stmt->execute($params);
		$result = $stmt->fetchAll();
		$ndpcal = $this->getNDPCal($row);

		$response->addDataSet(new DataSet("result", ["calculo" => $result, "ndpcal" => $ndpcal]));
	}

	public function getNDPCal($row) {
		$query = "SELECT SUM(QTPROTLIQU) QTPROTLIQU, SUM(QTPROTEINA) QTPROTTOTAL,(SUM(QTPROTEINA)*4 + SUM(QTALCOOL)*7 + SUM(QTLIPIDEO) * 9 + SUM(QTCARBOIDRATO)*4) VRCALORNUTR
									FROM (SELECT NVL(SUM(QTPROTLIQU),0) AS QTPROTLIQU, 0 QTPROTEINA, 0 QTALCOOL, 0 QTLIPIDEO, 0 QTCARBOIDRATO FROM NUTRTRAB WHERE (NRSEQUNUTR = :P_NRSEQUNUTR) AND (CDFILINUTR = :P_CDFILIAL) AND (CDSERVNUTR = :P_CDSERVFILI) AND (DTREFENUTR = :P_DTREFERENUTR) AND (CDDIETNUTR = 'XXXX' OR CDDIETNUTR = :P_CDDIETNUTR) AND (CDFAPRATNUTR = 'P' OR CDFAPRATNUTR = :P_CDFILIAL) AND ( (:P_CDPRATNUTR = 'T') OR (INSTR(:P_CDPRATNUTR, CDPRATNUTR) <> 0)) 
											UNION ALL SELECT 0 QTPROTLIQU, NVL(SUM(QTNUTRCALC),0) QTPROTEINA, 0 QTALCOOL, 0 QTLIPIDEO, 0 QTCARBOIDRATO FROM NUTRTRAB WHERE (NRSEQUNUTR = :P_NRSEQUNUTR) AND (CDFILINUTR = :P_CDFILIAL) AND (CDSERVNUTR = :P_CDSERVFILI) AND (DTREFENUTR = :P_DTREFERENUTR) AND (CDDIETNUTR = 'XXXX' OR CDDIETNUTR = :P_CDDIETNUTR) AND (CDFAPRATNUTR = 'P' OR CDFAPRATNUTR = :P_CDFILIAL) AND ( (:P_CDPRATNUTR = 'T') OR (INSTR(:P_CDPRATNUTR, CDPRATNUTR) <> 0)) AND (CDNUTRCALC = (SELECT MAX(CDPROTEINA) FROM PARAMGERAL)) 
											UNION ALL SELECT 0 QTPROTLIQU, 0 QTPROTEINA, NVL(SUM(QTNUTRCALC),0) QTALCOOL, 0 QTLIPIDEO, 0 QTCARBOIDRATO FROM NUTRTRAB WHERE (NRSEQUNUTR = :P_NRSEQUNUTR) AND (CDFILINUTR = :P_CDFILIAL) AND (CDSERVNUTR = :P_CDSERVFILI) AND (DTREFENUTR = :P_DTREFERENUTR) AND (CDDIETNUTR = 'XXXX' OR CDDIETNUTR = :P_CDDIETNUTR) AND (CDFAPRATNUTR = 'P' OR CDFAPRATNUTR = :P_CDFILIAL) AND ( (:P_CDPRATNUTR = 'T') OR (INSTR(:P_CDPRATNUTR, CDPRATNUTR) <> 0)) AND (CDNUTRCALC = (SELECT MAX(CDALCOOL) FROM PARAMGERAL)) 
											UNION ALL SELECT 0 QTPROTLIQU, 0 QTPROTEINA, 0 QTALCOOL, NVL(SUM(QTNUTRCALC),0) QTLIPIDEO, 0 QTCARBOIDRATO FROM NUTRTRAB WHERE (NRSEQUNUTR = :P_NRSEQUNUTR) AND (CDFILINUTR = :P_CDFILIAL) AND (CDSERVNUTR = :P_CDSERVFILI) AND (DTREFENUTR = :P_DTREFERENUTR) AND (CDDIETNUTR = 'XXXX' OR CDDIETNUTR = :P_CDDIETNUTR) AND (CDFAPRATNUTR = 'P' OR CDFAPRATNUTR = :P_CDFILIAL) AND ( (:P_CDPRATNUTR = 'T') OR (INSTR(:P_CDPRATNUTR, CDPRATNUTR) <> 0)) AND (CDNUTRCALC = (SELECT MAX(CDLIPIDIOS) FROM PARAMGERAL)) 
											UNION ALL SELECT 0 QTPROTLIQU, 0 QTPROTEINA, 0 QTALCOOL, 0 QTLIPIDEO, NVL(SUM(QTNUTRCALC),0) QTCARBOIDRATO FROM NUTRTRAB WHERE (NRSEQUNUTR = :P_NRSEQUNUTR) AND (CDFILINUTR = :P_CDFILIAL) AND (CDSERVNUTR = :P_CDSERVFILI) AND (DTREFENUTR = :P_DTREFERENUTR) AND (CDDIETNUTR = 'XXXX' OR CDDIETNUTR = :P_CDDIETNUTR) AND (CDFAPRATNUTR = 'P' OR CDFAPRATNUTR = :P_CDFILIAL) AND ( (:P_CDPRATNUTR = 'T') OR (INSTR(:P_CDPRATNUTR, CDPRATNUTR) <> 0)) AND (CDNUTRCALC = (SELECT MAX(CDCARBOHIDRA) FROM PARAMGERAL)))";
		$params = array(
			"P_NRSEQUNUTR" => $row['NRSEQUNUTR'],
			"P_CDFILIAL" 	 => $row['CDFILINUTR'],
			"P_CDSERVFILI" => $row['CDSERVNUTR'],
			"P_DTREFERENUTR" => $row['DTREFENUTR'],
			"P_CDDIETNUTR" => $row['CDDIETNUTR'],
			"P_CDPRATNUTR" => $row['CDPRATO'] 
		);
		$stmt = $this->connection->prepare($query);
		$stmt->execute($params);
		return $stmt->fetchAll();
	}
}