<?php
namespace PME\Controllers\Relatorios;

use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;

class EmissaoCardPeriodoController extends \Zeedhi\Framework\Controller\Report {

    protected $entityManager;
    protected $birtStrategy;
    protected $environment;
    protected $newCode;

    public function __construct(ReportService $reportService, $entityManager, $birtStrategy, $environment, $newCode) {
        $this->entityManager = $entityManager;
        $this->birtStrategy  = $birtStrategy;
        $this->environment   = $environment;
        $this->newCode       = $newCode;

        parent::__construct($reportService);
    }

    protected $reportMapping = array (
      'PME03000' => 
        array (
            'strategy' => 'BIRT',
            'parameterMapping' => 
            array (
              "DESCCARD"      => "P_DSCARDPME",
              "PERIODODE"     => "P_DTINICARDPME",
              "PERIODOATE"    => "P_DTFINCARDPME",
              "CDTIPOCARD"    => "P_CDTIPOCARD",
              "NMTIPOCARD"    => "P_NMTIPOCARD",
              "CDFILCENTPME"  => "P_CDFILCENTPME",
              "NMFILCENTPME"  => "P_NMFILCENTPME",
              "IMPCOMENSAIS"  => "P_IMPCOMENS",
              "NRSEQTRABCARD" => "P_NRSEQTRABCARD",
              "QUEBRAPAG"     => "P_IDQUEBRAPAGINA",
              "NMUNIDADE"     => "P_NMUNIDADE",
              "NRORG"         => "P_NRORG"
            )
        )
    );
    
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $nrorg = $this->environment->getNrOrgTrab();
        $row['NRSEQTRABCARD'] = $this->newCode->getCodeByTableName('LISTA'.$row['CDFILCENTPME'], $nrorg);
        $this->procedure($row);
        
        if(empty($row['CDSERVFILI'])){
          $row['CDSERVFILI'] = 'T';
        } else if(is_array($row['CDSERVFILI'])){
          $row['CDSERVFILI'] = join("_", $row['CDSERVFILI']);
        }
        
        if(empty($row['UNIDADE'])) $row['NMUNIDADE'] = "";
        else $row['NMUNIDADE'] = $row['UNIDADE']['CDFILIAL'].' '.$row['UNIDADE']['NMFILIAL'];

        $row['QUEBRAPAG'] = 'S';
        $row['NRORG'] = $nrorg;

        $this->birtStrategy->setReportLocale($this->environment->getLanguage());
        $this->birtStrategy->setReportFormat(strtolower($row['reportFormat']));
    }
    
    private function procedure($row){
      
      $nrorg = $this->environment->getNrOrgTrab();

      if(empty($row['CDFILIAL'])){
        $cdfilial = $row['CDFILCENTPME'];
      } else $cdfilial = $row['CDFILIAL'];
        
      if(empty($row['SERVICO'])){
        $servico = 'T';
      } else $servico = is_array($row['SERVICO']) ? join("_", $row['SERVICO']) : $row['SERVICO'];
      
      $connection = $this->entityManager->getConnection();
      $procedureCons = new StoredProcedure($connection, 'TRABRELCARDMES_PME');
      
      $procedureCons->addParam(new Param('P_NRORG',         Param::PARAM_INPUT, $nrorg,                Param::PARAM_TYPE_STR));
      $procedureCons->addParam(new Param('P_NRSEQTRABCARD', Param::PARAM_INPUT, $row['NRSEQTRABCARD'], Param::PARAM_TYPE_STR));
      $procedureCons->addParam(new Param('P_CDFILCENTPME',  Param::PARAM_INPUT, $row['CDFILCENTPME'],  Param::PARAM_TYPE_STR));
      $procedureCons->addParam(new Param('P_CDFILIAL',      Param::PARAM_INPUT, $cdfilial,             Param::PARAM_TYPE_STR));
      $procedureCons->addParam(new Param('P_NRCARDPME',     Param::PARAM_INPUT, $row['NRCARDPME'],     Param::PARAM_TYPE_STR));
      $procedureCons->addParam(new Param('P_DTINICIAL',     Param::PARAM_INPUT, $row['DTDE'],          Param::PARAM_TYPE_STR));
      $procedureCons->addParam(new Param('P_DTFINAL',       Param::PARAM_INPUT, $row['DTATE'],         Param::PARAM_TYPE_STR));
      $procedureCons->addParam(new Param('P_CDSERVFILI',    Param::PARAM_INPUT, $servico,              Param::PARAM_TYPE_STR));
      $procedureCons->addParam(new Param('P_QTCOLUNA',      Param::PARAM_INPUT, '4',                   Param::PARAM_TYPE_STR));
      $procedureCons->execute();
    }
}