<?php
namespace PME\Modules\Planejamento\Prato;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;

class ReceitaController extends \PME\Services\TeknisaCrud {

	protected $crudService;
	protected $parameterBag;
	protected $entityManager;
	protected $connection;
	protected $environment;

    public function __construct($crudService, $parameterBag, $entityManager, $connection, $environment) {
    	$this->entityManager = $entityManager;
    	$this->connection = $connection;
    	$this->environment = $environment;
        parent::__construct($crudService, $parameterBag);
	}

  
  public function visibilityFieldsReceita(DTO\Request $request, DTO\Response $response) {
    try {
        $cdfilial = $this->environment->getCdFilial();
        $sql = "SELECT P.CDFILIAL, P.IDQTLIQUBRUT, P.IDAPRERECE, P.IDGANHOCOCC, P.IDAPROVCOCC, P.IDPERDALIMP, P.IDAPROVLIMP,
                       P.IDTEMPPREP, P.IDBLOALTRELO, P.IDUTREQCOMPENTD, G.IDBLOPRATLOC, G.CDNVBLPRAT, P.IDUTDIASLIMSEG
                    FROM
                       PARAMGERAL G, PARAMPLANEJA P
                    WHERE
                       P.CDFILIAL = :P_CDFILIAL AND
                       P.CDPARPLANEJA = '1' AND
                       G.CDPARGERAL = '0001'";
                    
            $params = array(
                "P_CDFILIAL" => $cdfilial
            );
            $std = $this->entityManager->getConnection()->prepare($sql);
            $std->execute($params);
            
            $result = $std->fetchAll();

        $response->addDataset(new DataSet('result', $result[0]));
    } catch (\Exception $e) {
          throw new \Exception($e->getMessage(), $e->getCode());
      }
  }

  public function returnVisibilityFields($cdfilial) {
        try {
            $sql = "SELECT
                       P.CDFILIAL,
                       P.IDQTLIQUBRUT,
                       P.IDAPRERECE,
                       P.IDGANHOCOCC,
                       P.IDAPROVCOCC,
                       P.IDPERDALIMP,
                       P.IDAPROVLIMP,
                       P.IDTEMPPREP,
                       P.IDBLOALTRELO,
                       P.IDUTREQCOMPENTD,   
                       G.IDBLOPRATLOC,
                       G.CDNVBLPRAT,
                       P.IDUTDIASLIMSEG
                    FROM
                       PARAMGERAL G, PARAMPLANEJA P
                    WHERE
                       P.CDFILIAL = :P_CDFILIAL AND
                       P.CDPARPLANEJA = '1' AND
                       G.CDPARGERAL = '0001'";
                    
            $params = array(
                "P_CDFILIAL" => $cdfilial
            );
            $std = $this->entityManager->getConnection()->prepare($sql);
            $std->execute($params);
            
            return $std->fetchAll();
            
        } catch (\Exception $e) {
            throw $e;
        }
  }

  public function saveRecipeStandard(DTO\Request $request, DTO\Response $response) {
    try {
      $this->connection->beginTransaction();

      $rows = (Array) $request->getRow();
      foreach ($rows as $row) {

        if($row['__is_new']) {
          $query = "INSERT INTO RECEPADR (CDFILAUXPRAT, CDPRATO, CDPRODUTO, VRPEFATCORPR, SGUNIDADE, VRPEFATCOCPR, 
                QTPRODPRAT, HRTEMPPREPPR, QTUNIDESTPR, QTBRUTAPR, IDPRODBASEPR, CDAPRERECE, VRPEFATNUTPR, QTCALCNUTRPR, QTBRUTAPRUNR, IDQTDEFIXPR)
                VALUES (:CDFILAUXPRAT, :CDPRATO, :CDPRODUTO, :VRPEFATCORPR, :SGUNIDADE, :VRPEFATCOCPR, :QTPRODPRAT, :HRTEMPPREPPR, :QTUNIDESTPR, 
                  :QTBRUTAPR, :IDPRODBASEPR, :CDAPRERECE, :VRPEFATNUTPR, :QTCALCNUTRPR, :QTBRUTAPRUNR, :IDQTDEFIXPR)";
        } else {
          $query = "UPDATE RECEPADR SET VRPEFATCORPR = :VRPEFATCORPR, SGUNIDADE = :SGUNIDADE, VRPEFATCOCPR = :VRPEFATCOCPR, QTPRODPRAT = :QTPRODPRAT, HRTEMPPREPPR = :HRTEMPPREPPR, QTUNIDESTPR = :QTUNIDESTPR, 
                    QTBRUTAPR = :QTBRUTAPR, IDPRODBASEPR = :IDPRODBASEPR, CDAPRERECE = :CDAPRERECE, VRPEFATNUTPR = :VRPEFATNUTPR, QTCALCNUTRPR = :QTCALCNUTRPR, QTBRUTAPRUNR = :QTBRUTAPRUNR, IDQTDEFIXPR = :IDQTDEFIXPR
                    WHERE CDPRATO = :CDPRATO AND CDFILAUXPRAT = :CDFILAUXPRAT AND CDPRODUTO = :CDPRODUTO";
        }  
            
        $params = array(
          'CDFILAUXPRAT'  => $row['CDFILAUXPRAT'],
          'CDPRATO'       => $row['CDPRATO'],
          'CDPRODUTO'     => $row['CDPRODUTO'],
          'VRPEFATCORPR'  => $row['VRPEFATCORPR'],
          'SGUNIDADE'     => $row['SGUNIDADE'],
          'VRPEFATCOCPR'  => $row['VRPEFATCOCPR'],
          'QTPRODPRAT'    => $row['QTPRODPRAT'],
          'HRTEMPPREPPR'  => $row['HRTEMPPREPPR'],
          'QTUNIDESTPR'   => $row['QTUNIDESTPR'],
          'QTBRUTAPR'     => $row['QTBRUTAPR'],
          'IDPRODBASEPR'  => $row['IDPRODBASEPR'],
          'CDAPRERECE'    => $row['CDAPRERECE'],
          'VRPEFATNUTPR'  => $row['VRPEFATNUTPR'],
          'QTCALCNUTRPR'  => $row['QTCALCNUTRPR'],
          'QTBRUTAPRUNR'  => $row['QTBRUTAPRUNR'],
          'IDQTDEFIXPR'  => $row['IDQTDEFIXPR']
        );
            
        $this->connection->prepare($query)->execute($params);
      }
    
      $this->connection->commit();
      $response->addDataSet(new DataSet("columnsToReturn", $this->crudService->getColumnsToReturn()));
    } catch (\Exception $e) {
      $this->connection->rollback();
      $response->setError(new DTO\Response\Error($e->getMessage(), 1));
    }
  }

  public function saveRecipeTpCard(DTO\Request $request, DTO\Response $response) {
    try {
      $this->connection->beginTransaction();

      $rows = (Array) $request->getRow();
      foreach ($rows as $row) {

        if($row['__is_new']) {
          $query = "INSERT INTO RECETPCARD (CDFILAUXPRAT, CDPRATO, CDFILCENTPME, CDTIPOCARD, CDPRODUTO, VRPEFATCOCPRTP,
                        QTPRODPRATTP, VRPEFATCORPRTP, SGUNIDADE, HRTEMPPREPPRTP, QTUNIDESTPRTP, QTBRUTAPRTP,
                        IDPRODBASEPRTP, CDAPRERECE,VRPEFATNUTPRTP,QTCALCNUTRPRTP, QTBRUTAPRUNRTP, IDQTDEFIXPRTP)
                    VALUES (:CDFILAUXPRAT, :CDPRATO, :CDFILCENTPME, :CDTIPOCARD, :CDPRODUTO, :VRPEFATCOCPRTP,
                        :QTPRODPRATTP, :VRPEFATCORPRTP, :SGUNIDADE, :HRTEMPPREPPRTP, :QTUNIDESTPRTP, :QTBRUTAPRTP,
                        :IDPRODBASEPRTP, :CDAPRERECE,:VRPEFATNUTPRTP,:QTCALCNUTRPRTP, :QTBRUTAPRUNRTP, :IDQTDEFIXPRTP)";
        } else {
          $query = "UPDATE RECETPCARD SET VRPEFATCORPRTP = :VRPEFATCORPRTP, SGUNIDADE = :SGUNIDADE, VRPEFATCOCPRTP = :VRPEFATCOCPRTP, QTPRODPRATTP = :QTPRODPRATTP, HRTEMPPREPPRTP = :HRTEMPPREPPRTP, QTUNIDESTPRTP = :QTUNIDESTPRTP, 
                    QTBRUTAPRTP = :QTBRUTAPRTP, IDPRODBASEPRTP = :IDPRODBASEPRTP, CDAPRERECE = :CDAPRERECE, VRPEFATNUTPRTP = :VRPEFATNUTPRTP, QTCALCNUTRPRTP = :QTCALCNUTRPRTP, QTBRUTAPRUNRTP = :QTBRUTAPRUNRTP, IDQTDEFIXPRTP = :IDQTDEFIXPRTP
                    WHERE CDFILCENTPME = :CDFILCENTPME AND CDTIPOCARD = :CDTIPOCARD AND CDPRATO = :CDPRATO AND CDFILAUXPRAT = :CDFILAUXPRAT AND CDPRODUTO = :CDPRODUTO";
        }  
            
        $params = array(
          'CDFILCENTPME'  => $row['CDFILCENTPME'],
          'CDTIPOCARD'  => $row['CDTIPOCARD'],
          'CDFILAUXPRAT'  => $row['CDFILAUXPRAT'],
          'CDPRATO'       => $row['CDPRATO'],
          'CDPRODUTO'     => $row['CDPRODUTO'],
          'VRPEFATCORPRTP'  => $row['VRPEFATCORPRTP'],
          'SGUNIDADE'     => $row['SGUNIDADE'],
          'VRPEFATCOCPRTP'  => $row['VRPEFATCOCPRTP'],
          'QTPRODPRATTP'    => $row['QTPRODPRATTP'],
          'HRTEMPPREPPRTP'  => $row['HRTEMPPREPPRTP'],
          'QTUNIDESTPRTP'   => $row['QTUNIDESTPRTP'],
          'QTBRUTAPRTP'     => $row['QTBRUTAPRTP'],
          'IDPRODBASEPRTP'  => $row['IDPRODBASEPRTP'],
          'CDAPRERECE'    => $row['CDAPRERECE'],
          'VRPEFATNUTPRTP'  => $row['VRPEFATNUTPRTP'],
          'QTCALCNUTRPRTP'  => $row['QTCALCNUTRPRTP'],
          'QTBRUTAPRUNRTP'  => $row['QTBRUTAPRUNRTP'],
          'IDQTDEFIXPRTP'   => $row['IDQTDEFIXPRTP']
        );
            
        $this->connection->prepare($query)->execute($params);
      }
    
      $this->connection->commit();
      $response->addDataSet(new DataSet("columnsToReturn", $this->crudService->getColumnsToReturn()));
    } catch (\Exception $e) {
      $this->connection->rollback();
      $response->setError(new DTO\Response\Error($e->getMessage(), 1));
    }
  }

  public function saveRecipeLocal(DTO\Request $request, DTO\Response $response) {
    try {
      $this->connection->beginTransaction();

      $rows = (Array) $request->getRow();
      foreach ($rows as $row) {

        if($row['__is_new']) {
          $query = "INSERT INTO RECEFILI (CDFILAUXPRAT, CDPRATO, CDFILIAL, CDPRODUTO, SGUNIDADE, VRPEFATCOCLO, 
                      QTPRODRECLOC, VRPEFATCORLO, HRTEMPPREPLO, QTUNIDESTLO, QTBRUTALO, IDPRODBASELO, 
                      CDAPRERECE, VRPEFATNUTLO, QTCALCNUTRLO, QTBRUTALOUNR)
                  VALUES (:CDFILAUXPRAT, :CDPRATO, :CDFILIAL, :CDPRODUTO, :SGUNIDADE, :VRPEFATCOCLO, 
                      :QTPRODRECLOC, :VRPEFATCORLO, :HRTEMPPREPLO, :QTUNIDESTLO, :QTBRUTALO, 
                      :IDPRODBASELO, :CDAPRERECE, :VRPEFATNUTLO, :QTCALCNUTRLO, :QTBRUTALOUNR)";
        } else {
          $query = "UPDATE RECEFILI SET VRPEFATCORLO = :VRPEFATCORLO, SGUNIDADE = :SGUNIDADE, VRPEFATCOCLO = :VRPEFATCOCLO, QTPRODRECLOC = :QTPRODRECLOC, HRTEMPPREPLO = :HRTEMPPREPLO, QTUNIDESTLO = :QTUNIDESTLO, 
                    QTBRUTALO = :QTBRUTALO, IDPRODBASELO = :IDPRODBASELO, CDAPRERECE = :CDAPRERECE, VRPEFATNUTLO = :VRPEFATNUTLO, QTCALCNUTRLO = :QTCALCNUTRLO, QTBRUTALOUNR = :QTBRUTALOUNR
                    WHERE CDFILIAL = :CDFILIAL AND CDPRATO = :CDPRATO AND CDFILAUXPRAT = :CDFILAUXPRAT AND CDPRODUTO = :CDPRODUTO";
        }  
            
        $params = array(
          'CDFILIAL'  => $row['CDFILIAL'],
          'CDFILAUXPRAT'  => $row['CDFILAUXPRAT'],
          'CDPRATO'       => $row['CDPRATO'],
          'CDPRODUTO'     => $row['CDPRODUTO'],
          'VRPEFATCORLO'  => $row['VRPEFATCORLO'],
          'SGUNIDADE'     => $row['SGUNIDADE'],
          'VRPEFATCOCLO'  => $row['VRPEFATCOCLO'],
          'QTPRODRECLOC'  => $row['QTPRODRECLOC'],
          'HRTEMPPREPLO'  => $row['HRTEMPPREPLO'],
          'QTUNIDESTLO'   => $row['QTUNIDESTLO'],
          'QTBRUTALO'     => $row['QTBRUTALO'],
          'IDPRODBASELO'  => $row['IDPRODBASELO'],
          'CDAPRERECE'    => $row['CDAPRERECE'],
          'VRPEFATNUTLO'  => $row['VRPEFATNUTLO'],
          'QTCALCNUTRLO'  => $row['QTCALCNUTRLO'],
          'QTBRUTALOUNR'  => $row['QTBRUTALOUNR']
        );
        $this->connection->prepare($query)->execute($params);
      }
    
      $this->connection->commit();
      $response->addDataSet(new DataSet("columnsToReturn", $this->crudService->getColumnsToReturn()));
    } catch (\Exception $e) {
      $this->connection->rollback();
      $response->setError(new DTO\Response\Error($e->getMessage(), 1));
    }
  }

  public function saveRecipeService(DTO\Request $request, DTO\Response $response) {
    try {
      $this->connection->beginTransaction();

      $rows = (Array) $request->getRow();
      foreach ($rows as $row) {

        if($row['__is_new']) {
          $query = "INSERT INTO RECESERV (CDFILAUXPRAT, CDPRATO, CDFILIAL, CDSERVFILI, CDPRODUTO, VRPEFATCOCSE, 
                      QTPRODRECSER, VRPEFATCORSE, SGUNIDADE, HRTEMPPREPSE, QTUNIDESTSE, QTBRUTASE, 
                      IDPRODBASESE, CDAPRERECE,VRPEFATNUTSE,QTCALCNUTRSE, QTBRUTASEUNR)
                  VALUES (:CDFILAUXPRAT, :CDPRATO, :CDFILIAL, :CDSERVFILI, :CDPRODUTO, :VRPEFATCOCSE, 
                      :QTPRODRECSER, :VRPEFATCORSE, :SGUNIDADE, :HRTEMPPREPSE, :QTUNIDESTSE, 
                      :QTBRUTASE, :IDPRODBASESE, :CDAPRERECE, :VRPEFATNUTSE, :QTCALCNUTRSE, :QTBRUTASEUNR)
                  ";
        } else {
          $query = "UPDATE RECESERV SET VRPEFATCORSE = :VRPEFATCORSE, SGUNIDADE = :SGUNIDADE, VRPEFATCOCSE = :VRPEFATCOCSE, QTPRODRECSER = :QTPRODRECSER, HRTEMPPREPSE = :HRTEMPPREPSE, QTUNIDESTSE = :QTUNIDESTSE, 
                    QTBRUTASE = :QTBRUTASE, IDPRODBASESE = :IDPRODBASESE, CDAPRERECE = :CDAPRERECE, VRPEFATNUTSE = :VRPEFATNUTSE, QTCALCNUTRSE = :QTCALCNUTRSE, QTBRUTASEUNR = :QTBRUTASEUNR
                    WHERE CDFILIAL = :CDFILIAL AND CDSERVFILI = :CDSERVFILI AND  CDPRATO = :CDPRATO AND CDFILAUXPRAT = :CDFILAUXPRAT AND CDPRODUTO = :CDPRODUTO";
        }  
            
        $params = array(
          'CDFILIAL'  => $row['CDFILIAL'],
          'CDSERVFILI'  => $row['CDSERVFILI'],
          'CDFILAUXPRAT'  => $row['CDFILAUXPRAT'],
          'CDPRATO'       => $row['CDPRATO'],
          'CDPRODUTO'     => $row['CDPRODUTO'],
          'VRPEFATCORSE'  => $row['VRPEFATCORSE'],
          'SGUNIDADE'     => $row['SGUNIDADE'],
          'VRPEFATCOCSE'  => $row['VRPEFATCOCSE'],
          'QTPRODRECSER'    => $row['QTPRODRECSER'],
          'HRTEMPPREPSE'  => $row['HRTEMPPREPSE'],
          'QTUNIDESTSE'   => $row['QTUNIDESTSE'],
          'QTBRUTASE'     => $row['QTBRUTASE'],
          'IDPRODBASESE'  => $row['IDPRODBASESE'],
          'CDAPRERECE'    => $row['CDAPRERECE'],
          'VRPEFATNUTSE'  => $row['VRPEFATNUTSE'],
          'QTCALCNUTRSE'  => $row['QTCALCNUTRSE'],
          'QTBRUTASEUNR'  => $row['QTBRUTASEUNR']
        );

        $this->connection->prepare($query)->execute($params);
      }
    
      $this->connection->commit();
      $response->addDataSet(new DataSet("columnsToReturn", $this->crudService->getColumnsToReturn()));
    } catch (\Exception $e) {
      $this->connection->rollback();
      $response->setError(new DTO\Response\Error($e->getMessage(), 1));
    }
  }

  private function callSave($dataSourceName, $rowsToSave){
    $dataSet = new DataSet($dataSourceName, $rowsToSave);
    $request = new DTO\Request\DataSet($dataSet, "", "", "");  
    $rowsToSave = $this->crudService->getRowsToSave($request, $dataSourceName);
    $this->crudService->save($dataSourceName, $rowsToSave);
}
}